/****************************************************************************
** Meta object code from reading C++ file 'groupingcontainment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.6.4/applets/grouping/groupingcontainment.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'groupingcontainment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19GroupingContainmentE_t {};
} // unnamed namespace

template <> constexpr inline auto GroupingContainment::qt_create_metaobjectdata<qt_meta_tag_ZN19GroupingContainmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GroupingContainment",
        "newTask",
        "",
        "task",
        "showPlasmoidMenu",
        "QQuickItem*",
        "appletInterface",
        "x",
        "y",
        "popupPosition",
        "QPointF",
        "visualParent",
        "reorderItemBefore",
        "before",
        "after",
        "reorderItemAfter"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'newTask'
        QtMocHelpers::MethodData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'showPlasmoidMenu'
        QtMocHelpers::MethodData<void(QQuickItem *, int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'popupPosition'
        QtMocHelpers::MethodData<QPointF(QQuickItem *, int, int)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 5, 11 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'reorderItemBefore'
        QtMocHelpers::MethodData<void(QQuickItem *, QQuickItem *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 5, 14 },
        }}),
        // Method 'reorderItemAfter'
        QtMocHelpers::MethodData<void(QQuickItem *, QQuickItem *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 14 }, { 0x80000000 | 5, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GroupingContainment, qt_meta_tag_ZN19GroupingContainmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GroupingContainment::staticMetaObject = { {
    QMetaObject::SuperData::link<Plasma::Containment::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GroupingContainmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GroupingContainmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19GroupingContainmentE_t>.metaTypes,
    nullptr
} };

void GroupingContainment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GroupingContainment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->showPlasmoidMenu((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: { QPointF _r = _t->popupPosition((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->reorderItemBefore((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 4: _t->reorderItemAfter((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *GroupingContainment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GroupingContainment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GroupingContainmentE_t>.strings))
        return static_cast<void*>(this);
    return Plasma::Containment::qt_metacast(_clname);
}

int GroupingContainment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plasma::Containment::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
