// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_WEATHER_ION_ENVCAN_ENVCAN_DEBUG_H
#define ECM_QLOGGINGCATEGORY_WEATHER_ION_ENVCAN_ENVCAN_DEBUG_H

#include <QLoggingCategory>
 namespace WEATHER { namespace ION {
Q_DECLARE_LOGGING_CATEGORY(ENVCAN)
} } 

#endif
